@@ -1,10 +1,13 @@
 #[cfg(feature = "luau")]
 use full_moon::ast::types::TypeSpecifier;
-use full_moon::ast::{
-    punctuated::{Pair, Punctuated},
-    Assignment, Expression, LocalAssignment,
+use full_moon::tokenizer::{Token, TokenReference};
+use full_moon::{
+    ast::{
+        punctuated::{Pair, Punctuated},
+        Assignment, Expression, LocalAssignment,
+    },
+    tokenizer::TokenType,
 };
-use full_moon::tokenizer::{Token, TokenKind, TokenReference};
 
 #[cfg(feature = "luau")]
 use crate::formatters::luau::format_type_specifier;
@@ -72,20 +75,22 @@ fn hang_equal_token<'ast>(
     ctx: &Context,
     equal_token: TokenReference<'ast>,
     shape: Shape,
+    indent_first_item: bool,
 ) -> TokenReference<'ast> {
-    let equal_token_trailing_trivia = vec![
-        create_newline_trivia(ctx),
-        create_indent_trivia(ctx, shape.increment_additional_indent()),
-    ]
-    .iter()
-    .chain(
-        // Remove the space that was present after the equal token
-        equal_token
-            .trailing_trivia()
-            .skip_while(|x| x.token_kind() == TokenKind::Whitespace),
-    )
-    .map(|x| x.to_owned())
-    .collect();
+    let mut equal_token_trailing_trivia = vec![create_newline_trivia(ctx)];
+    if indent_first_item {
+        equal_token_trailing_trivia.push(create_indent_trivia(
+            ctx,
+            shape.increment_additional_indent(),
+        ))
+    }
+
+    let equal_token_trailing_trivia = equal_token
+        .trailing_trivia()
+        .filter(|x| trivia_util::trivia_is_comment(x))
+        .flat_map(|x| vec![Token::new(TokenType::spaces(1)), x.to_owned()])
+        .chain(equal_token_trailing_trivia.iter().map(|x| x.to_owned()))
+        .collect();
 
     equal_token.update_trailing_trivia(FormatTriviaType::Replace(equal_token_trailing_trivia))
 }
@@ -102,7 +107,7 @@ fn attempt_assignment_tactics<'ast>(
     // If there is, we should put it on multiple lines
     if expressions.len() > 1 {
         // First try hanging at the equal token, using an infinite width, to see if its enough
-        let hanging_equal_token = hang_equal_token(ctx, equal_token.to_owned(), shape);
+        let hanging_equal_token = hang_equal_token(ctx, equal_token.to_owned(), shape, true);
         let hanging_shape = shape.reset().increment_additional_indent();
         let expr_list = format_punctuated(
             ctx,
@@ -131,6 +136,46 @@ fn attempt_assignment_tactics<'ast>(
         }
     } else {
         // There is only a single element in the list
+        let expression = expressions.iter().next().unwrap();
+
+        // Special case: there is a comment in between the equals and the expression
+        if trivia_util::token_contains_comments(&equal_token)
+            || !trivia_util::expression_leading_comments(expression).is_empty()
+        {
+            // We will hang at the equals token, and then format the expression as necessary
+            let equal_token = hang_equal_token(ctx, equal_token, shape, false);
+
+            let shape = shape.reset().increment_additional_indent();
+
+            // As we know that there is only a single element in the list, we can extract it to work with it
+            let expression = format_expression(ctx, expression, shape);
+
+            // We need to take all the leading trivia from the expr_list
+            let (expression, leading_comments) =
+                trivia_util::take_expression_leading_comments(&expression);
+
+            // Indent each comment and trail them with a newline
+            let leading_comments = leading_comments
+                .iter()
+                .flat_map(|x| {
+                    vec![
+                        create_indent_trivia(ctx, shape),
+                        x.to_owned(),
+                        create_newline_trivia(ctx),
+                    ]
+                })
+                .chain(std::iter::once(create_indent_trivia(ctx, shape)))
+                .collect();
+
+            let expression =
+                expression.update_leading_trivia(FormatTriviaType::Replace(leading_comments));
+
+            // Rebuild expression back into a list
+            let expr_list = std::iter::once(Pair::new(expression, None)).collect();
+
+            return (expr_list, equal_token);
+        }
+
         // Create an example hanging the expression - we need to create a new context so that we don't overwrite it
         let hanging_expr_list = hang_punctuated_list(ctx, expressions, shape);
         let hanging_shape = shape.take_first_line(&strip_trivia(&hanging_expr_list));
@@ -147,7 +192,7 @@ fn attempt_assignment_tactics<'ast>(
             // Normal format is better: but check to see if the formatting is still over budget
             if formatting_shape.over_budget() {
                 // Hang at the equal token
-                let equal_token = hang_equal_token(ctx, equal_token, shape);
+                let equal_token = hang_equal_token(ctx, equal_token, shape, true);
                 // Add the expression list into the indent range, as it will be indented by one
                 let shape = shape.increment_additional_indent();
                 let expr_list = format_punctuated(ctx, expressions, shape, format_expression);
@@ -169,13 +214,14 @@ pub fn format_assignment<'ast>(
     let leading_trivia = vec![create_indent_trivia(ctx, shape)];
     let trailing_trivia = vec![create_newline_trivia(ctx)];
 
-    // Check if the assignment expressions contain comments. If they do, we bail out of determining any tactics
+    // Check if the assignment expressions or equal token contain comments. If they do, we bail out of determining any tactics
     // and format multiline
-    let contains_comments = assignment.expressions().pairs().any(|pair| {
-        pair.punctuation()
-            .map_or(false, |x| trivia_util::token_contains_comments(x))
-            || trivia_util::expression_contains_inline_comments(pair.value())
-    });
+    let contains_comments = trivia_util::token_contains_comments(assignment.equal_token())
+        || assignment.expressions().pairs().any(|pair| {
+            pair.punctuation()
+                .map_or(false, |x| trivia_util::token_contains_comments(x))
+                || trivia_util::expression_contains_inline_comments(pair.value())
+        });
 
     // Firstly attempt to format the assignment onto a single line, using an infinite column width shape
     let mut var_list = try_format_punctuated(
@@ -280,13 +326,16 @@ pub fn format_local_assignment<'ast>(
     if assignment.expressions().is_empty() {
         format_local_no_assignment(ctx, assignment, shape, leading_trivia, trailing_trivia)
     } else {
-        // Check if the assignment expressions contain comments. If they do, we bail out of determining any tactics
+        // Check if the assignment expression or equals token contain comments. If they do, we bail out of determining any tactics
         // and format multiline
-        let contains_comments = assignment.expressions().pairs().any(|pair| {
-            pair.punctuation()
-                .map_or(false, |x| trivia_util::token_contains_comments(x))
-                || trivia_util::expression_contains_inline_comments(pair.value())
-        });
+        let contains_comments = assignment
+            .equal_token()
+            .map_or(false, |x| trivia_util::token_contains_comments(x))
+            || assignment.expressions().pairs().any(|pair| {
+                pair.punctuation()
+                    .map_or(false, |x| trivia_util::token_contains_comments(x))
+                    || trivia_util::expression_contains_inline_comments(pair.value())
+            });
 
         // Firstly attempt to format the assignment onto a single line, using an infinite column width shape
         let local_token = fmt_symbol!(ctx, assignment.local_token(), "local ", shape)
